package com.budderfly.aws.gateway.service;

import com.budderfly.aws.gateway.config.KinesisFirehoseConfiguration;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import software.amazon.awssdk.services.firehose.model.FirehoseResponse;


@Service
public class KinesisFirehosePowerService extends KinesisFirehoseService {

    Logger logger = LoggerFactory.getLogger(KinesisFirehosePowerService.class);

    public KinesisFirehosePowerService(KinesisFirehoseConfiguration kinesisFirehoseConfiguration) {
        super(kinesisFirehoseConfiguration.getPowerAccessKey(), kinesisFirehoseConfiguration.getPowerSecretKey(), kinesisFirehoseConfiguration.getRegion(), kinesisFirehoseConfiguration.getPowerStream());
    }

    /**
     * This method is invoked when there is an exception in sending a log record
     * to Kinesis.
     */
    @Override
    public final void accept(FirehoseResponse response, Throwable exception) {
        if (exception != null) {
            logger.error("Failed to publish records to kinesis with exception: {} - {} - {} response: {}", exception.getMessage(), exception.toString(), exception.getCause(), response);
        } else {
            logger.debug("Succeeded to publish records to kinesis with response: {}", response.toString());
        }
    }

}
